instancelib.machinelearning.featurematrix module
================================================

.. automodule:: instancelib.machinelearning.featurematrix
   :members:
   :undoc-members:
   :show-inheritance:
